==> mlpack_4.5.1.orig.tar.xz: mlpack-4.5.1/doc/citation.md <==
# Citation details

If you use mlpack in your research or software, please cite mlpack using the
citation for
[the paper below](https://joss.theoj.org/papers/10.21105/joss.05026):

 * ***mlpack 4: a fast, header-only C++ machine learning library***.  R.R.
   Curtin, M. Edel, O. Shrit, S. Agrawal, S. Basak, J.J. Balamuta, R.
   Birmingham, K. Dutt, D. Eddelbuettel, R. Garg, S. Jaiswal, A. Kaushik, S.
   Kim, A. Mukherjee, N.G. Sai, N. Sharma, Y.S. Parihar, R. Swain, C. Sanderson.
   _Journal of Open Source Software_ 8:82, p. 5026, 2023.

In BibTeX format:

```
@article{mlpack2023,
    title     = {mlpack 4: a fast, header-only C++ machine learning library},
    author    = {Ryan R. Curtin and Marcus Edel and Omar Shrit and
                 Shubham Agrawal and Suryoday Basak and James J. Balamuta and
                 Ryan Birmingham and Kartik Dutt and Dirk Eddelbuettel and
                 Rishabh Garg and Shikhar Jaiswal and Aakash Kaushik and
                 Sangyeon Kim and Anjishnu Mukherjee and Nanubala Gnana Sai and
                 Nippun Sharma and Yashwant Singh Parihar and Roshan Swain and
                 Conrad Sanderson},
    journal   = {Journal of Open Source Software},
    volume    = {8},
    number    = {82},
    pages     = {5026},
    year      = {2023},
    doi       = {10.21105/joss.05026},
    url       = {https://doi.org/10.21105/joss.05026}
}
```

Citations are beneficial for the growth and improvement of mlpack.

### Older papers

See also the following older papers concerning mlpack, its community, and its
internal design.

 * [mlpack 3: a fast, flexible machine learning
   library](https://joss.theoj.org/papers/10.21105/joss.00726) (2018)

 * [mlpack open-source machine learning library and
   community](http://kurg.org/pub/pdf/2018mlossmlpack.pdf) (2018)

 * [Designing and building the mlpack open-source machine learning
   library](https://arxiv.org/abs/1708.05279) (2017)

 * [mlpack: a scalable C++ machine learning
   library](https://www.jmlr.org/papers/volume14/curtin13a/curtin13a.pdf) (2013)

==> mlpack_4.6.0.orig.tar.xz: mlpack-4.6.0/doc/citation.md <==
# Citation details

If you use mlpack in your research or software, please cite mlpack using the
citation for
[the paper below](https://joss.theoj.org/papers/10.21105/joss.05026):

 * ***mlpack 4: a fast, header-only C++ machine learning library***.  R.R.
   Curtin, M. Edel, O. Shrit, S. Agrawal, S. Basak, J.J. Balamuta, R.
   Birmingham, K. Dutt, D. Eddelbuettel, R. Garg, S. Jaiswal, A. Kaushik, S.
   Kim, A. Mukherjee, N.G. Sai, N. Sharma, Y.S. Parihar, R. Swain, C. Sanderson.
   _Journal of Open Source Software_ 8:82, p. 5026, 2023.

In BibTeX format:

```
@article{mlpack2023,
    title     = {mlpack 4: a fast, header-only C++ machine learning library},
    author    = {Ryan R. Curtin and Marcus Edel and Omar Shrit and
                 Shubham Agrawal and Suryoday Basak and James J. Balamuta and
                 Ryan Birmingham and Kartik Dutt and Dirk Eddelbuettel and
                 Rishabh Garg and Shikhar Jaiswal and Aakash Kaushik and
                 Sangyeon Kim and Anjishnu Mukherjee and Nanubala Gnana Sai and
                 Nippun Sharma and Yashwant Singh Parihar and Roshan Swain and
                 Conrad Sanderson},
    journal   = {Journal of Open Source Software},
    volume    = {8},
    number    = {82},
    pages     = {5026},
    year      = {2023},
    doi       = {10.21105/joss.05026},
    url       = {https://doi.org/10.21105/joss.05026}
}
```

Citations are beneficial for the growth and improvement of mlpack.

### Older papers

See also the following older papers concerning mlpack, its community, and its
internal design.

 * [mlpack 3: a fast, flexible machine learning
   library](https://joss.theoj.org/papers/10.21105/joss.00726) (2018)

 * [mlpack open-source machine learning library and
   community](https://openreview.net/pdf?id=rJxx0Y6NhX) (2018)

 * [Designing and building the mlpack open-source machine learning
   library](https://arxiv.org/abs/1708.05279) (2017)

 * [mlpack: a scalable C++ machine learning
   library](https://www.jmlr.org/papers/volume14/curtin13a/curtin13a.pdf) (2013)
